@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | Zend Engine                                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1998-2001 Zend Technologies Ltd. (http://www.zend.com) |
+   | Copyright (c) 1998-2003 Zend Technologies Ltd. (http://www.zend.com) |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 0.92 of the Zend license,     |
+   | This source file is subject to version 2.00 of the Zend license,     |
    | that is bundled with this package in the file LICENSE, and is        | 
-   | available at through the world-wide-web at                           |
-   | http://www.zend.com/license/0_92.txt.                                |
+   | available through the world-wide-web at the following url:           |
+   | http://www.zend.com/license/2_00.txt.                                |
    | If you did not receive a copy of the Zend license and are unable to  |
    | obtain it through the world-wide-web, please send a note to          |
    | license@zend.com so we can mail you a copy immediately.              |
@@ -28,12 +28,21 @@
 #include "zend_ptr_stack.h"
 #include "zend_constants.h"
 #include "zend_extensions.h"
+#include "zend_execute_globals.h"
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #endif
 
 
 ZEND_API void (*zend_execute)(zend_op_array *op_array TSRMLS_DC);
+ZEND_API void (*zend_execute_internal)(zend_execute_data *execute_data_ptr, int return_value_used TSRMLS_DC);
+
+ZEND_API void execute_internal(zend_execute_data *execute_data_ptr, int return_value_used TSRMLS_DC) 
+{
+	((zend_internal_function *) execute_data_ptr->function_state.function)->handler(execute_data_ptr->opline->extended_value, execute_data_ptr->Ts[execute_data_ptr->opline->result.u.var].var.ptr, execute_data_ptr->object.ptr, return_value_used TSRMLS_CC);
+}
+
+
 
 #ifdef ZEND_WIN32
 #include <process.h>
@@ -113,6 +122,8 @@ static int is_not_internal_class(zend_class_entry *ce TSRMLS_DC)
 void init_executor(TSRMLS_D)
 {
 	INIT_ZVAL(EG(uninitialized_zval));
+    /* trick to make uninitialized_zval never be modified, passed by ref, etc. */
+	EG(uninitialized_zval).refcount++;
 	INIT_ZVAL(EG(error_zval));
 	EG(uninitialized_zval_ptr)=&EG(uninitialized_zval);
 	EG(error_zval_ptr)=&EG(error_zval);
@@ -147,9 +158,9 @@ void init_executor(TSRMLS_D)
 
 	EG(user_error_handler) = NULL;
 
-	zend_ptr_stack_init(&EG(user_error_handlers));
+	EG(current_execute_data) = NULL;
 
-	EG(orig_error_reporting) = EG(error_reporting);
+	zend_ptr_stack_init(&EG(user_error_handlers));
 
 	EG(full_tables_cleanup) = 0;
 #ifdef ZEND_WIN32
@@ -190,13 +201,16 @@ void shutdown_executor(TSRMLS_D)
 		}
 	} zend_end_try();
 
-	/* The regular list must be destroyed after the main symbol table and
-	 * op arrays are destroyed.
+	zend_try {
+		clean_non_persistent_constants(TSRMLS_C);
+	} zend_end_try();
+
+	/* The regular list must be destroyed after the main symbol table,
+	 * op arrays, and constants are destroyed.
 	 */
 	zend_destroy_rsrc_list(&EG(regular_list) TSRMLS_CC);
 
 	zend_try {
-		clean_non_persistent_constants(TSRMLS_C);
 #if ZEND_DEBUG
 	signal(SIGSEGV, original_sigsegv_handler);
 #endif
@@ -210,14 +224,15 @@ void shutdown_executor(TSRMLS_D)
 
 		zend_ptr_stack_clean(&EG(user_error_handlers), ZVAL_DESTRUCTOR, 1);
 		zend_ptr_stack_destroy(&EG(user_error_handlers));
-
-		EG(error_reporting) = EG(orig_error_reporting);
 	} zend_end_try();
 }
 
 
 ZEND_API char *get_active_function_name(TSRMLS_D)
 {
+	if (!zend_is_executing(TSRMLS_C)) {
+		return NULL;
+	}
 	switch(EG(function_state_ptr)->function->type) {
 		case ZEND_USER_FUNCTION: {
 				char *function_name = ((zend_op_array *) EG(function_state_ptr)->function)->function_name;
@@ -316,7 +331,7 @@ ZEND_API int zval_update_constant(zval **pp, void *arg TSRMLS_DC)
 		INIT_PZVAL(p);
 		p->refcount = refcount;
 	} else if (p->type == IS_CONSTANT_ARRAY) {
-		zval **element;
+		zval **element, *new_val;
 		char *str_index;
 		uint str_index_len;
 		ulong num_index;
@@ -342,19 +357,38 @@ ZEND_API int zval_update_constant(zval **pp, void *arg TSRMLS_DC)
 				zend_hash_move_forward(p->value.ht);
 				continue;
 			}
+
+			if(const_value.type == IS_STRING &&
+			   const_value.value.str.len == str_index_len-1 &&
+			   !strncmp(const_value.value.str.val, str_index, str_index_len)) {
+				/* constant value is the same as its name */
+				zval_dtor(&const_value);
+				zend_hash_move_forward(p->value.ht);
+				continue;
+			}
+
+			ALLOC_ZVAL(new_val);
+			*new_val = **element;
+			zval_copy_ctor(new_val);
+			new_val->refcount = 1;
+			new_val->is_ref = 0;
+			
+			/* preserve this bit for inheritance */
+			Z_TYPE_PP(element) |= IS_CONSTANT_INDEX;
+			
 			switch (const_value.type) {
 				case IS_STRING:
-					zend_hash_update(p->value.ht, const_value.value.str.val, const_value.value.str.len+1, element, sizeof(zval *), NULL);
-					(*element)->refcount++;
+					zend_hash_update(p->value.ht, const_value.value.str.val, const_value.value.str.len+1, &new_val, sizeof(zval *), NULL);
 					break;
 				case IS_LONG:
-					zend_hash_index_update(p->value.ht, const_value.value.lval, element, sizeof(zval *), NULL);
-					(*element)->refcount++;
+					zend_hash_index_update(p->value.ht, const_value.value.lval, &new_val, sizeof(zval *), NULL);
 					break;
 			}
 			zend_hash_del(p->value.ht, str_index, str_index_len);
+			zval_dtor(&const_value);
 		}
 		zend_hash_apply_with_argument(p->value.ht, (apply_func_arg_t) zval_update_constant, (void *) 1 TSRMLS_CC);
+		zend_hash_internal_pointer_reset(p->value.ht);
 	}
 	return 0;
 }
@@ -386,7 +420,6 @@ int call_user_function_ex(HashTable *function_table, zval **object_pp, zval *fun
 	int i;
 	zval **original_return_value;
 	HashTable *calling_symbol_table;
-	zend_function_state function_state;
 	zend_function_state *original_function_state_ptr;
 	zend_op_array *original_op_array;
 	zend_op **original_opline_ptr;
@@ -395,6 +428,16 @@ int call_user_function_ex(HashTable *function_table, zval **object_pp, zval *fun
 	int (*orig_binary_op)(zval *result, zval *op1, zval *op2 TSRMLS_DC);
 	zval function_name_copy;
 
+	zend_execute_data execute_data;
+
+	/* Initialize execute_data */
+	EX(fbc) = NULL;
+	EX(object).ptr = NULL;
+	EX(ce) = NULL;
+	EX(Ts) = NULL;
+	EX(op_array) = NULL;
+	EX(opline) = NULL;
+
 	*retval_ptr_ptr = NULL;
 
 	if (function_name->type==IS_ARRAY) { /* assume array($obj, $name) couple */
@@ -418,6 +461,7 @@ int call_user_function_ex(HashTable *function_table, zval **object_pp, zval *fun
 	if (object_pp) {
 		if (Z_TYPE_PP(object_pp) == IS_OBJECT) {
 			function_table = &(*object_pp)->value.obj.ce->function_table;
+			EX(object).ptr = *object_pp;
 		} else if (Z_TYPE_PP(object_pp) == IS_STRING) {
 			zend_class_entry *ce;
 			char *lc_class;
@@ -431,6 +475,7 @@ int call_user_function_ex(HashTable *function_table, zval **object_pp, zval *fun
 				return FAILURE;
 
 			function_table = &ce->function_table;
+			EX(ce) = ce;
 			object_pp = NULL;
 		} else
 			return FAILURE;
@@ -445,7 +490,7 @@ int call_user_function_ex(HashTable *function_table, zval **object_pp, zval *fun
 	zend_str_tolower(function_name_copy.value.str.val, function_name_copy.value.str.len);
 
 	original_function_state_ptr = EG(function_state_ptr);
-	if (zend_hash_find(function_table, function_name_copy.value.str.val, function_name_copy.value.str.len+1, (void **) &function_state.function)==FAILURE) {
+	if (zend_hash_find(function_table, function_name_copy.value.str.val, function_name_copy.value.str.len+1, (void **) &EX(function_state).function)==FAILURE) {
 		zval_dtor(&function_name_copy);
 		return FAILURE;
 	}
@@ -454,14 +499,19 @@ int call_user_function_ex(HashTable *function_table, zval **object_pp, zval *fun
 	for (i=0; i<param_count; i++) {
 		zval *param;
 
-		if (function_state.function->common.arg_types
-			&& i<function_state.function->common.arg_types[0]
-			&& function_state.function->common.arg_types[i+1]==BYREF_FORCE
+		if (EX(function_state).function->common.arg_types
+			&& i<EX(function_state).function->common.arg_types[0]
+			&& EX(function_state).function->common.arg_types[i+1]==BYREF_FORCE
 			&& !PZVAL_IS_REF(*params[i])) {
 			if ((*params[i])->refcount>1) {
 				zval *new_zval;
 
 				if (no_separation) {
+					if(i) {
+						/* hack to clean up the stack */
+						zend_ptr_stack_n_push(&EG(argument_stack), 2, (void *) (long) i, NULL);
+						zend_ptr_stack_clear_multiple(TSRMLS_C);
+					}
 					return FAILURE;
 				}
 				ALLOC_ZVAL(new_zval);
@@ -487,9 +537,12 @@ int call_user_function_ex(HashTable *function_table, zval **object_pp, zval *fun
 
 	zend_ptr_stack_n_push(&EG(argument_stack), 2, (void *) (long) param_count, NULL);
 
-	EG(function_state_ptr) = &function_state;
+	EG(function_state_ptr) = &EX(function_state);
 
-	if (function_state.function->type == ZEND_USER_FUNCTION) {
+	EX(prev_execute_data) = EG(current_execute_data);
+	EG(current_execute_data) = &execute_data;
+
+	if (EX(function_state).function->type == ZEND_USER_FUNCTION) {
 		calling_symbol_table = EG(active_symbol_table);
 		if (symbol_table) {
 			EG(active_symbol_table) = symbol_table;
@@ -508,7 +561,7 @@ int call_user_function_ex(HashTable *function_table, zval **object_pp, zval *fun
 		original_return_value = EG(return_value_ptr_ptr);
 		original_op_array = EG(active_op_array);
 		EG(return_value_ptr_ptr) = retval_ptr_ptr;
-		EG(active_op_array) = (zend_op_array *) function_state.function;
+		EG(active_op_array) = (zend_op_array *) EX(function_state).function;
 		original_opline_ptr = EG(opline_ptr);
 		orig_free_op1 = EG(free_op1);
 		orig_free_op2 = EG(free_op2);
@@ -528,12 +581,27 @@ int call_user_function_ex(HashTable *function_table, zval **object_pp, zval *fun
 		EG(unary_op) = orig_unary_op;
 		EG(binary_op) = orig_binary_op;
 	} else {
+		zend_op temp_op;
 		ALLOC_INIT_ZVAL(*retval_ptr_ptr);
-		((zend_internal_function *) function_state.function)->handler(param_count, *retval_ptr_ptr, (object_pp?*object_pp:NULL), 1 TSRMLS_CC);
+		temp_op.extended_value = param_count;
+		temp_op.result.u.var = 0;
+		temp_op.lineno = 0;
+
+		EX(opline) = &temp_op;
+		EX(Ts) = (temp_variable *) do_alloca(sizeof(temp_variable)*1);
+		EX(Ts)[EX(opline)->result.u.var].var.ptr = *retval_ptr_ptr;
+
+		if (!zend_execute_internal) {
+			((zend_internal_function *) EX(function_state).function)->handler(EX(opline)->extended_value, EX(Ts)[EX(opline)->result.u.var].var.ptr, EX(object).ptr, 1 TSRMLS_CC);
+		} else {
+			zend_execute_internal(&execute_data, 1 TSRMLS_CC);
+		}
 		INIT_PZVAL(*retval_ptr_ptr);
+		free_alloca(EX(Ts));
 	}
 	zend_ptr_stack_clear_multiple(TSRMLS_C);
 	EG(function_state_ptr) = original_function_state_ptr;
+	EG(current_execute_data) = EX(prev_execute_data);
 
 	return SUCCESS;
 }
@@ -660,9 +728,10 @@ ZEND_API void zend_timeout(int dummy)
 {
 	TSRMLS_FETCH();
 
-	/* is there any point in this?  we're terminating the request anyway...
-	PG(connection_status) |= PHP_CONNECTION_TIMEOUT;
-	*/
+	if (zend_on_timeout) {
+		zend_on_timeout(EG(timeout_seconds) TSRMLS_CC);
+	}
+
 	zend_error(E_ERROR, "Maximum execution time of %d second%s exceeded",
 			  EG(timeout_seconds), EG(timeout_seconds) == 1 ? "" : "s");
 }
@@ -680,7 +749,15 @@ static LRESULT CALLBACK zend_timeout_WndProc(HWND hWnd, UINT message, WPARAM wPa
 			if (lParam==0) {
 				KillTimer(timeout_window, wParam);
 			} else {
+				void ***tsrm_ls;
+
 				SetTimer(timeout_window, wParam, lParam*1000, NULL);
+				tsrm_ls = ts_resource_ex(0, &wParam);
+				if (!tsrm_ls) {
+					/* shouldn't normally happen */
+					break;
+				}
+				EG(timed_out) = 0;
 			}
 			break;
 		case WM_UNREGISTER_ZEND_TIMEOUT:
@@ -785,10 +862,18 @@ void zend_set_timeout(long seconds)
 		t_r.it_value.tv_sec = seconds;
 		t_r.it_value.tv_usec = t_r.it_interval.tv_sec = t_r.it_interval.tv_usec = 0;
 
+#	ifdef __CYGWIN__
+		setitimer(ITIMER_REAL, &t_r, NULL);
+		signal(SIGALRM, zend_timeout);
+		sigemptyset(&sigset);
+		sigaddset(&sigset, SIGALRM);
+#	else
 		setitimer(ITIMER_PROF, &t_r, NULL);
 		signal(SIGPROF, zend_timeout);
 		sigemptyset(&sigset);
 		sigaddset(&sigset, SIGPROF);
+#	endif
+
 		sigprocmask(SIG_UNBLOCK, &sigset, NULL);
 	}
 #	endif
@@ -807,7 +892,12 @@ void zend_unset_timeout(TSRMLS_D)
 
 		no_timeout.it_value.tv_sec = no_timeout.it_value.tv_usec = no_timeout.it_interval.tv_sec = no_timeout.it_interval.tv_usec = 0;
 
+#ifdef __CYGWIN__
+		setitimer(ITIMER_REAL, &no_timeout, NULL);
+#else
 		setitimer(ITIMER_PROF, &no_timeout, NULL);
+#endif
+
 	}
 #	endif
 #endif
