@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | Zend Engine                                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1998-2001 Zend Technologies Ltd. (http://www.zend.com) |
+   | Copyright (c) 1998-2003 Zend Technologies Ltd. (http://www.zend.com) |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 0.92 of the Zend license,     |
+   | This source file is subject to version 2.00 of the Zend license,     |
    | that is bundled with this package in the file LICENSE, and is        | 
-   | available at through the world-wide-web at                           |
-   | http://www.zend.com/license/0_92.txt.                                |
+   | available through the world-wide-web at the following url:           |
+   | http://www.zend.com/license/2_00.txt.                                |
    | If you did not receive a copy of the Zend license and are unable to  |
    | obtain it through the world-wide-web, please send a note to          |
    | license@zend.com so we can mail you a copy immediately.              |
@@ -31,6 +31,7 @@
 #include "zend_list.h"
 #include "zend_fast_cache.h"
 #include "zend_API.h"
+#include "zend_strtod.h"
 
 #if 0&&WITH_BCMATH
 #include "ext/bcmath/number.h"
@@ -43,7 +44,7 @@ ZEND_API int zend_atoi(const char *str, int str_len)
 	if (!str_len) {
 		str_len = strlen(str);
 	}
-	retval = atoi(str);
+	retval = strtol(str, NULL, 0);
 	if (str_len>0) {
 		switch (str[str_len-1]) {
 			case 'k':
@@ -184,6 +185,7 @@ ZEND_API void convert_scalar_to_number(zval *op TSRMLS_DC)
 
 #define DVAL_TO_LVAL(d, l) (l) = (d) > LONG_MAX ? (unsigned long) (d) : (long) (d)
 
+
 #define zendi_convert_to_long(op, holder, result)					\
 	if (op==result) {												\
 		convert_to_long(op);										\
@@ -333,7 +335,7 @@ ZEND_API void convert_to_double(zval *op)
 		case IS_STRING:
 			strval = op->value.str.val;
 
-			op->value.dval = strtod(strval, NULL);
+			op->value.dval = zend_strtod(strval, NULL);
 			STR_FREE(strval);
 			break;
 		case IS_ARRAY:
@@ -460,16 +462,16 @@ ZEND_API void _convert_to_string(zval *op ZEND_FILE_LINE_DC)
 			break;
 		}
 		case IS_ARRAY:
+			zend_error(E_NOTICE, "Array to string conversion");
 			zval_dtor(op);
 			op->value.str.val = estrndup_rel("Array", sizeof("Array")-1);
 			op->value.str.len = sizeof("Array")-1;
-			zend_error(E_NOTICE, "Array to string conversion");
 			break;
 		case IS_OBJECT:
+			zend_error(E_NOTICE, "Object to string conversion");
 			zval_dtor(op);
 			op->value.str.val = estrndup_rel("Object", sizeof("Object")-1);
 			op->value.str.len = sizeof("Object")-1;
-			zend_error(E_NOTICE, "Object to string conversion");
 			break;
 		default:
 			zval_dtor(op);
@@ -621,15 +623,17 @@ ZEND_API int add_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
 	zendi_convert_scalar_to_number(op1, op1_copy, result);
 	zendi_convert_scalar_to_number(op2, op2_copy, result);
 
-
 	if (op1->type == IS_LONG && op2->type == IS_LONG) {
-		double dval = (double) op1->value.lval + (double) op2->value.lval;
+		long lval = op1->value.lval + op2->value.lval;
 
-		if ((dval > (double) LONG_MAX) || (dval < (double) LONG_MIN)) {
-			result->value.dval = dval;
+		/* check for overflow by comparing sign bits */
+		if ( (op1->value.lval & LONG_MIN) == (op2->value.lval & LONG_MIN)
+			&& (op1->value.lval & LONG_MIN) != (lval & LONG_MIN)) {
+
+			result->value.dval = (double) op1->value.lval + (double) op2->value.lval;
 			result->type = IS_DOUBLE;
 		} else {
-			result->value.lval = op1->value.lval + op2->value.lval;
+			result->value.lval = lval;
 			result->type = IS_LONG;
 		}
 		return SUCCESS;
@@ -655,18 +659,21 @@ ZEND_API int add_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
 ZEND_API int sub_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
 {
 	zval op1_copy, op2_copy;
-	
+
 	zendi_convert_scalar_to_number(op1, op1_copy, result);
 	zendi_convert_scalar_to_number(op2, op2_copy, result);
 
 	if (op1->type == IS_LONG && op2->type == IS_LONG) {
-		double dval = (double) op1->value.lval - (double) op2->value.lval;
+		long lval = op1->value.lval - op2->value.lval;
 
-		if ((dval < (double) LONG_MIN) || (dval > (double) LONG_MAX)) {
-			result->value.dval = dval;
+		/* check for overflow by comparing sign bits */
+		if ( (op1->value.lval & LONG_MIN) != (op2->value.lval & LONG_MIN)
+			&& (op1->value.lval & LONG_MIN) != (lval & LONG_MIN)) {
+
+			result->value.dval = (double) op1->value.lval - (double) op2->value.lval;
 			result->type = IS_DOUBLE;
 		} else {
-			result->value.lval = op1->value.lval - op2->value.lval;
+			result->value.lval = lval;
 			result->type = IS_LONG;
 		}
 		return SUCCESS;
@@ -688,39 +695,48 @@ ZEND_API int sub_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
 	return FAILURE;				/* unknown datatype */
 }
 
+#include "zend_multiply.h"
 
-ZEND_API int mul_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
+ZEND_API int mul_function(zval *return_value, zval *op1, zval *op2 TSRMLS_DC)
 {
 	zval op1_copy, op2_copy;
+	zend_uchar tx;
 	
-	zendi_convert_scalar_to_number(op1, op1_copy, result);
-	zendi_convert_scalar_to_number(op2, op2_copy, result);
+	zendi_convert_scalar_to_number(op1, op1_copy, return_value);
+	zendi_convert_scalar_to_number(op2, op2_copy, return_value);
 
-	if (op1->type == IS_LONG && op2->type == IS_LONG) {
-		double dval = (double) op1->value.lval * (double) op2->value.lval;
+#define ZEND_SHIFT_WIDTH 4
+	
+	tx = op1->type | (op2->type << ZEND_SHIFT_WIDTH);
+	
+	switch (tx) {
+	case (IS_LONG | (IS_LONG << ZEND_SHIFT_WIDTH)): {
+		int use_dval;
+			
+		ZEND_SIGNED_MULTIPLY_LONG(op1->value.lval, op2->value.lval, 
+					return_value->value.lval, return_value->value.dval, 
+					use_dval);
 
-		if ((dval > (double) LONG_MAX) || (dval < (double) LONG_MIN)) {
-			result->value.dval = dval;
-			result->type = IS_DOUBLE;
-		} else {
-			result->value.lval = op1->value.lval * op2->value.lval;
-			result->type = IS_LONG;
-		}
+		return_value->type = use_dval ? IS_DOUBLE : IS_LONG;
+		
 		return SUCCESS;
 	}
-	if ((op1->type == IS_DOUBLE && op2->type == IS_LONG)
-		|| (op1->type == IS_LONG && op2->type == IS_DOUBLE)) {
-		result->value.dval = (op1->type == IS_LONG ?
-						 (((double) op1->value.lval) * op2->value.dval) :
-						 (op1->value.dval * ((double) op2->value.lval)));
-		result->type = IS_DOUBLE;
+	
+	case (IS_DOUBLE | (IS_DOUBLE << ZEND_SHIFT_WIDTH)):
+		RETVAL_DOUBLE(op1->value.dval * op2->value.dval);
 		return SUCCESS;
-	}
-	if (op1->type == IS_DOUBLE && op2->type == IS_DOUBLE) {
-		result->type = IS_DOUBLE;
-		result->value.dval = op1->value.dval * op2->value.dval;
+
+	case (IS_DOUBLE | (IS_LONG << ZEND_SHIFT_WIDTH)):
+		RETVAL_DOUBLE(op1->value.dval * (double) op2->value.lval);
+		return SUCCESS;
+
+	case (IS_LONG | (IS_DOUBLE << ZEND_SHIFT_WIDTH)):
+		RETVAL_DOUBLE(op2->value.dval * (double) op1->value.lval);
 		return SUCCESS;
 	}
+
+#undef ZEND_SHIFT_WIDTH
+	
 	zend_error(E_ERROR, "Unsupported operand types");
 	return FAILURE;				/* unknown datatype */
 }
@@ -777,6 +793,11 @@ ZEND_API int mod_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
 		return FAILURE;			/* modulus by zero */
 	}
 
+	if (abs(op2->value.lval) == 1) {
+		ZVAL_LONG(result, 0);
+		return SUCCESS;
+	}
+
 	result->type = IS_LONG;
 	result->value.lval = op1->value.lval % op2->value.lval;
 	return SUCCESS;
@@ -797,7 +818,7 @@ ZEND_API int boolean_xor_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
 }
 
 
-ZEND_API int boolean_not_function(zval *result, zval *op1 TSRMLS_DC)
+ZEND_API int boolean_not_function(zval *result, zval *op1)
 {
 	zval op1_copy;
 	
@@ -809,7 +830,7 @@ ZEND_API int boolean_not_function(zval *result, zval *op1 TSRMLS_DC)
 }
 
 
-ZEND_API int bitwise_not_function(zval *result, zval *op1 TSRMLS_DC)
+ZEND_API int bitwise_not_function(zval *result, zval *op1)
 {
 	zval op1_copy = *op1;
 	
@@ -864,7 +885,7 @@ ZEND_API int bitwise_or_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
 			result_str[i] |= shorter->value.str.val[i];
 		}
 		if (result==op1) {
-			efree(result->value.str.val);
+			STR_FREE(result->value.str.val);
 		}
 		result->value.str.val = result_str;
 		result->value.str.len = result_len;
@@ -903,7 +924,7 @@ ZEND_API int bitwise_and_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
 			result_str[i] &= longer->value.str.val[i];
 		}
 		if (result==op1) {
-			efree(result->value.str.val);
+			STR_FREE(result->value.str.val);
 		}
 		result->value.str.val = result_str;
 		result->value.str.len = result_len;
@@ -944,7 +965,7 @@ ZEND_API int bitwise_xor_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
 			result_str[i] ^= longer->value.str.val[i];
 		}
 		if (result==op1) {
-			efree(result->value.str.val);
+			STR_FREE(result->value.str.val);
 		}
 		result->value.str.val = result_str;
 		result->value.str.len = result_len;
@@ -1002,7 +1023,11 @@ ZEND_API int add_string_to_string(zval *result, zval *op1, zval *op2)
 {
 	int length = op1->value.str.len + op2->value.str.len;
 
-	result->value.str.val = (char *) erealloc(op1->value.str.val, length+1);
+	if (op1->value.str.val==empty_string) {
+		result->value.str.val = (char *) emalloc(length+1);
+	} else {
+		result->value.str.val = (char *) erealloc(op1->value.str.val, length+1);
+	}
     memcpy(result->value.str.val+op1->value.str.len, op2->value.str.val, op2->value.str.len);
     result->value.str.val[length] = 0;
 	result->value.str.len = length;
@@ -1083,6 +1108,35 @@ ZEND_API int string_compare_function(zval *result, zval *op1, zval *op2 TSRMLS_D
 	return SUCCESS;
 }
 
+#if HAVE_STRCOLL
+ZEND_API int string_locale_compare_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
+{
+	zval op1_copy, op2_copy;
+	int use_copy1, use_copy2;
+
+	zend_make_printable_zval(op1, &op1_copy, &use_copy1);
+	zend_make_printable_zval(op2, &op2_copy, &use_copy2);
+
+	if (use_copy1) {
+		op1 = &op1_copy;
+	}
+	if (use_copy2) {
+		op2 = &op2_copy;
+	}
+
+	result->value.lval = strcoll(op1->value.str.val, op2->value.str.val);
+	result->type = IS_LONG;
+
+	if (use_copy1) {
+		zval_dtor(op1);
+	}
+	if (use_copy2) {
+		zval_dtor(op2);
+	}
+	return SUCCESS;
+}
+#endif
+
 ZEND_API int numeric_compare_function(zval *result, zval *op1, zval *op2 TSRMLS_DC)
 {
 	zval op1_copy, op2_copy;
@@ -1439,7 +1493,13 @@ ZEND_API int increment_function(zval *op1)
 {
 	switch (op1->type) {
 		case IS_LONG:
-			op1->value.lval++;
+			if(op1->value.lval == LONG_MAX) {
+				/* switch to double */
+				double d = (double)op1->value.lval;
+				ZVAL_DOUBLE(op1, d+1);
+			} else {
+				op1->value.lval++;
+			} 
 			break;
 		case IS_DOUBLE:
 			op1->value.dval = op1->value.dval + 1;
@@ -1455,14 +1515,20 @@ ZEND_API int increment_function(zval *op1)
 
 				switch (is_numeric_string(strval, op1->value.str.len, &lval, &dval, 0)) {
 					case IS_LONG:
-						op1->value.lval = lval+1;
-						op1->type = IS_LONG;
-						efree(strval);
+						if(lval == LONG_MAX) {
+							/* switch to double */
+							double d = (double)lval;
+							ZVAL_DOUBLE(op1, d+1);
+						} else {
+							op1->value.lval = lval+1;
+							op1->type = IS_LONG;
+						}
+						efree(strval); /* should never be empty_string */
 						break;
 					case IS_DOUBLE:
 						op1->value.dval = dval+1;
 						op1->type = IS_DOUBLE;
-						efree(strval);
+						efree(strval); /* should never be empty_string */
 						break;
 #if 0
 					case FLAG_IS_BC:
@@ -1485,25 +1551,43 @@ ZEND_API int increment_function(zval *op1)
 ZEND_API int decrement_function(zval *op1)
 {
 	long lval;
+	double dval;
 	
 	switch (op1->type) {
 		case IS_LONG:
-			op1->value.lval--;
+			if(op1->value.lval == LONG_MIN) {
+				double d = (double)op1->value.lval;
+				ZVAL_DOUBLE(op1, d-1);
+			} else {
+				op1->value.lval--;
+			}
 			break;
 		case IS_DOUBLE:
 			op1->value.dval = op1->value.dval - 1;
 			break;
 		case IS_STRING:		/* Like perl we only support string increment */
-			if (op1->value.str.len==0) { /* consider as 0 */
+			if (op1->value.str.len == 0) { /* consider as 0 */
 				STR_FREE(op1->value.str.val);
 				op1->value.lval = -1;
 				op1->type = IS_LONG;
 				break;
-			} else if (is_numeric_string(op1->value.str.val, op1->value.str.len, &lval, NULL, 0)==IS_LONG) { /* long */
-				STR_FREE(op1->value.str.val);
-				op1->value.lval = lval-1;
-				op1->type = IS_LONG;
-				break;
+			}
+			switch(is_numeric_string(op1->value.str.val, op1->value.str.len, &lval, &dval, 0)) {
+				case IS_LONG:
+					STR_FREE(op1->value.str.val);
+					if(lval == LONG_MIN) {
+						double d = (double)lval;
+						ZVAL_DOUBLE(op1, d-1);
+					} else {
+						op1->value.lval = lval-1;
+						op1->type = IS_LONG;
+					}
+					break;
+				case IS_DOUBLE:
+					STR_FREE(op1->value.str.val);
+					op1->value.dval = dval - 1;
+					op1->type = IS_DOUBLE;
+					break;
 			}
 			break;
 		default:
@@ -1520,18 +1604,18 @@ ZEND_API int zval_is_true(zval *op)
 	return (op->value.lval ? 1 : 0);
 }
 
-
 ZEND_API void zend_str_tolower(char *str, unsigned int length)
 {
 	register char *p=str, *end=p+length;
 	
 	while (p<end) {
-		*p = tolower(*p);
+		if (*p >= 'A' && *p <= 'Z') {
+			*p = (*p)+32;
+		}	
 		p++;
 	}
 }
 
-
 ZEND_API int zend_binary_strcmp(char *s1, uint len1, char *s2, uint len2)
 {
 	int retval;
@@ -1565,8 +1649,8 @@ ZEND_API int zend_binary_strcasecmp(char *s1, uint len1, char *s2, uint len2)
 	len = MIN(len1, len2);
 
 	while (len--) {
-		c1 = tolower(*s1++);
-		c2 = tolower(*s2++);
+		c1 = tolower((int)*(unsigned char *)s1++);
+		c2 = tolower((int)*(unsigned char *)s2++);
 		if (c1 != c2) {
 			return c1 - c2;
 		}
@@ -1584,8 +1668,8 @@ ZEND_API int zend_binary_strncasecmp(char *s1, uint len1, char *s2, uint len2, u
 	len = MIN(length, MIN(len1, len2));
 
 	while (len--) {
-		c1 = tolower(*s1++);
-		c2 = tolower(*s2++);
+		c1 = tolower((int)*(unsigned char *)s1++);
+		c2 = tolower((int)*(unsigned char *)s2++);
 		if (c1 != c2) {
 			return c1 - c2;
 		}
@@ -1644,9 +1728,9 @@ ZEND_API void zendi_smart_strcmp(zval *result, zval *s1, zval *s2)
 #endif
 		if ((ret1==IS_DOUBLE) || (ret2==IS_DOUBLE)) {
 			if (ret1!=IS_DOUBLE) {
-				dval1 = strtod(s1->value.str.val, NULL);
+				dval1 = zend_strtod(s1->value.str.val, NULL);
 			} else if (ret2!=IS_DOUBLE) {
-				dval2 = strtod(s2->value.str.val, NULL);
+				dval2 = zend_strtod(s2->value.str.val, NULL);
 			}
 			result->value.dval = dval1 - dval2;
 			result->value.lval = ZEND_NORMALIZE_BOOL(result->value.dval);
@@ -1700,3 +1784,14 @@ ZEND_API void zend_compare_objects(zval *result, zval *o1, zval *o2 TSRMLS_DC)
 	}
 	zend_compare_symbol_tables(result, Z_OBJPROP_P(o1), Z_OBJPROP_P(o2) TSRMLS_CC);
 }
+
+ZEND_API void zend_locale_sprintf_double(zval *op ZEND_FILE_LINE_DC)
+{
+	double dval = op->value.dval;
+	
+	TSRMLS_FETCH();
+	
+	op->value.str.val = (char *) emalloc_rel(MAX_LENGTH_OF_DOUBLE + EG(precision) + 1);
+	sprintf(op->value.str.val, "%.*G", (int) EG(precision), dval);
+	op->value.str.len = strlen(op->value.str.val);
+}
