@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2002 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: php_db.h,v 1.16.2.1 2002/08/27 01:07:36 helly Exp $ */
+/* $Id: php_db.h,v 1.18.2.1.8.1 2006/01/01 13:46:51 sniper Exp $ */
 
 
 #ifndef PHP_DB_H
@@ -55,10 +55,10 @@ dbm_info *php_find_dbm(pval *id TSRMLS_DC);
 void php_dbm_close(zend_rsrc_list_entry *rsrc TSRMLS_DC);
 dbm_info *php_dbm_open(char *filename, char *mode TSRMLS_DC);
 char *php_dbm_fetch(dbm_info *info, char *key TSRMLS_DC);
-int php_dbm_insert_replace(dbm_info *info, char *key, char *value, int insert_mode TSRMLS_DC);
-int php_dbm_exists(dbm_info *info, char *key);
-int php_dbm_delete(dbm_info *info, char *key);
-char *php_dbm_first_key(dbm_info *info);
+int php_dbm_insert_replace(dbm_info *info, char *key, char *value, int replace_mode TSRMLS_DC);
+int php_dbm_exists(dbm_info *info, char *key TSRMLS_DC);
+int php_dbm_delete(dbm_info *info, char *key TSRMLS_DC);
+char *php_dbm_first_key(dbm_info *info TSRMLS_DC);
 char *php_dbm_nextkey(dbm_info *info, char *key TSRMLS_DC);
 
 /* db file functions */
