@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | msession 1.0                                                         |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2003 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -1266,7 +1266,7 @@ PS_OPEN_FUNC(msession)
 {
 	int port;
 	int len = strlen(save_path)+1;
-	char * path = alloca(len);
+	char * path = emalloc(len);
 	char * szport;
 
 	strcpy(path, save_path);
@@ -1285,7 +1285,13 @@ PS_OPEN_FUNC(msession)
 	
 	ELOG( "ps_open_msession");
 	PS_SET_MOD_DATA((void *)1); /* session.c needs a non-zero here! */
-	return PHPMsessionConnect(path, port) ? SUCCESS : FAILURE;
+	if (PHPMsessionConnect(path, port)) {
+		efree(path);
+		return SUCCESS;
+	} else {
+		efree(path);
+		return FAILURE;
+	}
 }
 
 PS_CLOSE_FUNC(msession)
