@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: php_mssql.c,v 1.86.2.44.2.10 2006/01/01 13:46:55 sniper Exp $ */
+/* $Id: php_mssql.c,v 1.86.2.44.2.11 2006/04/04 18:50:16 fmk Exp $ */
 
 #ifdef COMPILE_DL_MSSQL
 #define HAVE_MSSQL 1
@@ -222,6 +222,7 @@ static void _free_mssql_result(zend_rsrc_list_entry *rsrc TSRMLS_DC)
 	mssql_result *result = (mssql_result *)rsrc->ptr;
 
 	_free_result(result, 1);
+	dbcancel(result->mssql_ptr->link);
 	efree(result);
 }
 
@@ -1230,6 +1231,7 @@ PHP_FUNCTION(mssql_query)
 	}
 	if (dbsqlexec(mssql_ptr->link)==FAIL || (retvalue = dbresults(mssql_ptr->link))==FAIL) {
 		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Query failed");
+		dbcancel(mssql_ptr->link);
 		RETURN_FALSE;
 	}
 	
@@ -1244,6 +1246,7 @@ PHP_FUNCTION(mssql_query)
 
 	retvalue=dbnextrow(mssql_ptr->link);	
 	if (retvalue==FAIL) {
+		dbcancel(mssql_ptr->link);
 		RETURN_FALSE;
 	}
 
@@ -2182,6 +2185,7 @@ PHP_FUNCTION(mssql_execute)
 
 	if (dbrpcexec(mssql_ptr->link)==FAIL || dbsqlok(mssql_ptr->link)==FAIL) {
 		php_error_docref(NULL TSRMLS_CC, E_WARNING, "stored procedure execution failed");
+		dbcancel(mssql_ptr->link);
 		RETURN_FALSE;
 	}
 
@@ -2189,6 +2193,7 @@ PHP_FUNCTION(mssql_execute)
 
 	if (retval_results==FAIL) {
 		php_error_docref(NULL TSRMLS_CC, E_WARNING, "could not retrieve results");
+		dbcancel(mssql_ptr->link);
 		RETURN_FALSE;
 	}
 
