@@ -1,26 +1,26 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
    | Authors: Stig Sther Bakken <ssb@fast.no>                            |
    |          Mitch Golden <mgolden@interport.net>                        |
-   |          Rasmus Lerdorf <rasmus@lerdorf.on.ca>                       |
+   |          Rasmus Lerdorf <rasmus@php.net>                             |
    |          Andreas Karajannis <Andreas.Karajannis@gmd.de>              |
    |          Thies C. Arntzen <thies@thieso.net>                         |
    +----------------------------------------------------------------------+
  */
 
-/* $Id: oracle.c,v 1.71.2.1 2001/10/11 23:51:50 ssb Exp $ */
+/* $Id: oracle.c,v 1.80.2.2.8.1 2006/01/01 13:46:55 sniper Exp $ */
 
 /* comment out the next line if you're on Oracle 7.x and don't have the olog 
    call. */
@@ -53,10 +53,6 @@
 #define PHP_ORA_API
 #endif                                   
 
-#ifndef PHP_WIN32
-#include "build-defs.h"
-#endif 
-
 #ifdef ZTS
 int ora_globals_id;
 #else
@@ -71,7 +67,7 @@ PHP_ORA_API php_ora_globals ora_globals;
 static oraCursor *ora_get_cursor(HashTable *, pval ** TSRMLS_DC);
 static char *ora_error(Cda_Def *);
 static int ora_describe_define(oraCursor *);
-static int _close_oraconn(zend_rsrc_list_entry *rsrc TSRMLS_DC);
+static void _close_oraconn(zend_rsrc_list_entry *rsrc TSRMLS_DC);
 static int _close_oracur(oraCursor *cur TSRMLS_DC);
 static int _ora_ping(oraConnection *conn);
 int ora_set_param_values(oraCursor *cursor, int isout TSRMLS_DC);
@@ -113,6 +109,8 @@ PHP_RSHUTDOWN_FUNCTION(oracle);
 PHP_MINFO_FUNCTION(oracle);
 /* }}} */
 
+static unsigned char second_args_force_ref[] = { 2, BYREF_NONE, BYREF_FORCE };
+
 /* {{{ oracle_functions[]
  */
 function_entry oracle_functions[] = {
@@ -126,7 +124,7 @@ function_entry oracle_functions[] = {
 	PHP_FE(ora_errorcode,							NULL)
 	PHP_FE(ora_exec,								NULL)
 	PHP_FE(ora_fetch,								NULL)
-   	PHP_FE(ora_fetch_into,							second_arg_force_ref)
+   	PHP_FE(ora_fetch_into,							second_args_force_ref)
 	PHP_FE(ora_columntype,							NULL)
 	PHP_FE(ora_columnname,							NULL)
 	PHP_FE(ora_columnsize,							NULL)
@@ -203,7 +201,7 @@ ZEND_GET_MODULE(oracle)
 
 /* {{{ _close_oraconn
  */
-static int _close_oraconn(zend_rsrc_list_entry *rsrc TSRMLS_DC)
+static void _close_oraconn(zend_rsrc_list_entry *rsrc TSRMLS_DC)
 {
 	oraConnection *conn = (oraConnection *)rsrc->ptr;
 	
@@ -220,8 +218,6 @@ static int _close_oraconn(zend_rsrc_list_entry *rsrc TSRMLS_DC)
 	} else {
 		efree(conn);
 	}
-
-	return 1;
 }
 /* }}} */
 
@@ -434,8 +430,8 @@ void ora_do_logon(INTERNAL_FUNCTION_PARAMETERS, int persistent)
 	convert_to_string_ex(arg1);
 	convert_to_string_ex(arg2);
   
-	user = (*arg1)->value.str.val;
-	passwd = (*arg2)->value.str.val;
+	user = Z_STRVAL_PP(arg1);
+	passwd = Z_STRVAL_PP(arg2);
 
 	hashed_details_length = sizeof("oracle__")-1+strlen(user)+strlen(passwd);
 	hashed_details = (char *) emalloc(hashed_details_length+1);
@@ -487,7 +483,7 @@ void ora_do_logon(INTERNAL_FUNCTION_PARAMETERS, int persistent)
 			}
 
 			/* hash it up */
-			new_le.type = le_pconn;
+			Z_TYPE(new_le) = le_pconn;
 			new_le.ptr = db_conn;
 			if (zend_hash_update(&EG(persistent_list), hashed_details, hashed_details_length+1, (void *) &new_le, sizeof(list_entry), NULL)==FAILURE) {
 				free(db_conn);
@@ -498,7 +494,7 @@ void ora_do_logon(INTERNAL_FUNCTION_PARAMETERS, int persistent)
 			ORA(num_links)++;
 			zend_hash_add(ORA(conns),(void*)&db_conn,sizeof(void*),(void*)&db_conn,sizeof(void*),NULL);
 		} else {  /* we do */
-			if (le->type != le_pconn) {
+			if (Z_TYPE_P(le) != le_pconn) {
 				RETURN_FALSE;
 			}
 
@@ -535,15 +531,15 @@ void ora_do_logon(INTERNAL_FUNCTION_PARAMETERS, int persistent)
 			int type,link;
 			void *ptr;
 
-			if (index_ptr->type != le_index_ptr) {
+			if (Z_TYPE_P(index_ptr) != le_index_ptr) {
 				RETURN_FALSE;
 			}
 			link = (int) index_ptr->ptr;
 			ptr = zend_list_find(link,&type);   /* check if the link is still there */
 			if (ptr && (type==le_conn || type==le_pconn)) {
 				zend_list_addref(link);
-				return_value->value.lval = link;
-				return_value->type = IS_RESOURCE;
+				Z_LVAL_P(return_value) = link;
+				Z_TYPE_P(return_value) = IS_RESOURCE;
 				efree(hashed_details);
 				return;
 			} else {
@@ -578,8 +574,8 @@ void ora_do_logon(INTERNAL_FUNCTION_PARAMETERS, int persistent)
 		ZEND_REGISTER_RESOURCE(return_value, db_conn, le_conn);
 
 		/* add it to the hash */
-		new_index_ptr.ptr = (void *) return_value->value.lval;
-		new_index_ptr.type = le_index_ptr;
+		new_index_ptr.ptr = (void *) Z_LVAL_P(return_value);
+		Z_TYPE(new_index_ptr) = le_index_ptr;
 		if (zend_hash_update(&EG(regular_list),hashed_details,hashed_details_length+1,(void *) &new_index_ptr, sizeof(list_entry), NULL)==FAILURE) {
 			efree(hashed_details);
 			RETURN_FALSE;
@@ -604,7 +600,9 @@ PHP_FUNCTION(ora_logoff)
 	}
 	ZEND_FETCH_RESOURCE2(conn, oraConnection *, arg, -1, "Oracle-Connection", le_conn, le_pconn);
 
-	zend_list_delete((*arg)->value.lval);
+	zend_list_delete(Z_LVAL_PP(arg));
+
+	RETURN_TRUE;
 }
 /* }}} */
 
@@ -635,7 +633,7 @@ PHP_FUNCTION(ora_open)
 	cursor->open = 1;
 	cursor->conn_ptr = conn;	
 	ZEND_REGISTER_RESOURCE(return_value, cursor, le_cursor);
-	cursor->conn_id = return_value->value.lval;
+	cursor->conn_id = Z_LVAL_P(return_value);
 }
 
 /* }}} */
@@ -652,7 +650,7 @@ PHP_FUNCTION(ora_close)
 	}
 	ZEND_FETCH_RESOURCE(cursor, oraCursor *, arg, -1, "Oracle-Cursor", le_cursor);
 
-	zend_list_delete((*arg)->value.lval);
+	zend_list_delete(Z_LVAL_PP(arg));
 
 	RETURN_TRUE;
 }
@@ -755,7 +753,7 @@ PHP_FUNCTION(ora_parse)
 	case 3:
 		zend_get_parameters_ex(3,&curs,&sql,&def);
 		convert_to_long_ex(def);
-		if ((*def)->value.lval) {
+		if (Z_LVAL_PP(def)) {
 			defer = DEFER_PARSE;
 		}
 		break;
@@ -767,7 +765,7 @@ PHP_FUNCTION(ora_parse)
 	}
 
 	convert_to_string_ex(sql);
- 	query = (text *) estrndup((*sql)->value.str.val,(*sql)->value.str.len);
+ 	query = (text *) estrndup(Z_STRVAL_PP(sql),Z_STRLEN_PP(sql));
 
 	if (query == NULL) {
 		php_error(E_WARNING, "Invalid query");
@@ -815,7 +813,7 @@ PHP_FUNCTION(ora_bind)
 	case 5:
 		zend_get_parameters_ex(5,&curs,&pvar,&svar,&plen,&ptyp);
 		convert_to_long_ex(ptyp);
-		inout = (*ptyp)->value.lval;
+		inout = Z_LVAL_PP(ptyp);
 		break;
 	case 4:
 		zend_get_parameters_ex(4,&curs,&pvar,&svar,&plen);
@@ -847,13 +845,13 @@ PHP_FUNCTION(ora_bind)
 		RETURN_FALSE;
 	}
 
-	if ((paramname = estrndup((*pvar)->value.str.val, (*pvar)->value.str.len)) == NULL) {
+	if ((paramname = estrndup(Z_STRVAL_PP(pvar), Z_STRLEN_PP(pvar))) == NULL) {
 		php_error(E_WARNING, "Out of memory for parametername");
 		efree(newparam);
 		RETURN_FALSE;
 	}
 
-	if (zend_hash_add(cursor->params, paramname, (*pvar)->value.str.len + 1, 
+	if (zend_hash_add(cursor->params, paramname, Z_STRLEN_PP(pvar) + 1, 
 					  newparam, sizeof(oraParam), (void **)&paramptr) == FAILURE) {
 		/* XXX zend_hash_destroy */
 		efree(paramname);
@@ -865,7 +863,7 @@ PHP_FUNCTION(ora_bind)
 	efree(newparam);
 	efree(paramname);
 	
-	paramptr->progvl = (*plen)->value.lval + 1;
+	paramptr->progvl = Z_LVAL_PP(plen) + 1;
 	paramptr->inout = inout;
 
 	if ((paramptr->progv = (text *)emalloc(paramptr->progvl)) == NULL) {
@@ -877,7 +875,7 @@ PHP_FUNCTION(ora_bind)
 	paramptr->alen = paramptr->progvl;
 
 	if (obndra(&cursor->cda,              
-			   (*svar)->value.str.val,
+			   Z_STRVAL_PP(svar),
 			   -1,
 			   (ub1 *)paramptr->progv,
 			   paramptr->progvl,
@@ -1006,7 +1004,7 @@ PHP_FUNCTION(ora_do)
 
 	memset(cursor, 0, sizeof(oraCursor));
 
-	query = (text *) estrndup((*sql)->value.str.val,(*sql)->value.str.len);
+	query = (text *) estrndup(Z_STRVAL_PP(sql),Z_STRLEN_PP(sql));
 
 	if (query == NULL) {
 		php_error(E_WARNING, "Invalid query in Ora_Do");
@@ -1023,7 +1021,7 @@ PHP_FUNCTION(ora_do)
 	}
 	cursor->open = 1;
 	cursor->conn_ptr = conn;	
-	cursor->conn_id = (*con)->value.lval;	
+	cursor->conn_id = Z_LVAL_PP(con);	
 	
 	/* Prepare stmt */
 
@@ -1111,7 +1109,7 @@ PHP_FUNCTION(ora_fetch_into)
 	case 3:
 		zend_get_parameters_ex(3, &curs, &arr, &flg);
 		convert_to_long_ex(flg);
-		flags = (*flg)->value.lval;
+		flags = Z_LVAL_PP(flg);
 		break;
 		
 	default:
@@ -1137,14 +1135,14 @@ PHP_FUNCTION(ora_fetch_into)
 	}
 	cursor->fetched++;
 
-	if ((*arr)->type != IS_ARRAY){
+	if (Z_TYPE_PP(arr) != IS_ARRAY){
 		pval_destructor(*arr);
 	    if (array_init(*arr) == FAILURE){
 			php_error(E_WARNING, "Can't convert to type Array");
 			RETURN_FALSE;
 		}
 	}
-	zend_hash_internal_pointer_reset((*arr)->value.ht);
+	zend_hash_internal_pointer_reset(Z_ARRVAL_PP(arr));
 
 	for (i = 0; i < cursor->ncols; i++) {
 		if (cursor->columns[i].col_retcode == 1405) {
@@ -1166,8 +1164,8 @@ PHP_FUNCTION(ora_fetch_into)
 		} else {
 			MAKE_STD_ZVAL(tmp);
 
-			tmp->type = IS_STRING;
-			tmp->value.str.len = 0;
+			Z_TYPE_P(tmp) = IS_STRING;
+			Z_STRLEN_P(tmp) = 0;
 
 			switch(cursor->columns[i].dbtype) {
 				case SQLT_LNG:
@@ -1205,24 +1203,24 @@ PHP_FUNCTION(ora_fetch_into)
 							}
 						}
 						if (cursor->columns[i].buf && offset) {
-							tmp->value.str.len = offset;
+							Z_STRLEN_P(tmp) = offset;
 						} else {
-							tmp->value.str.len = 0;
+							Z_STRLEN_P(tmp) = 0;
 						}
 					}
 					break;
 				default:
-					tmp->value.str.len = min(cursor->columns[i].col_retlen,
+					Z_STRLEN_P(tmp) = min(cursor->columns[i].col_retlen,
 											 cursor->columns[i].dsize);
 					break;
 			}
-			tmp->value.str.val = estrndup(cursor->columns[i].buf,tmp->value.str.len);
+			Z_STRVAL_P(tmp) = estrndup(cursor->columns[i].buf,Z_STRLEN_P(tmp));
 		}
 
 		if (flags&ORA_FETCHINTO_ASSOC){
-			zend_hash_update((*arr)->value.ht, cursor->columns[i].cbuf, cursor->columns[i].cbufl+1, (void *) &tmp, sizeof(pval*), NULL);
+			zend_hash_update(Z_ARRVAL_PP(arr), cursor->columns[i].cbuf, cursor->columns[i].cbufl+1, (void *) &tmp, sizeof(pval*), NULL);
 		} else {
-			zend_hash_index_update((*arr)->value.ht, i, (void *) &tmp, sizeof(pval*), NULL);
+			zend_hash_index_update(Z_ARRVAL_PP(arr), i, (void *) &tmp, sizeof(pval*), NULL);
 		}
 
 	}
@@ -1253,18 +1251,18 @@ PHP_FUNCTION(ora_columnname)
 		RETURN_FALSE;
 	}
         
-	if ((*col)->value.lval >= cursor->ncols){
+	if (Z_LVAL_PP(col) >= cursor->ncols){
 		php_error(E_WARNING, "Column index larger than number of columns");
 		RETURN_FALSE;
 	}
 
-	if ((*col)->value.lval < 0){
+	if (Z_LVAL_PP(col) < 0){
 		php_error(E_WARNING, "Column numbering starts at 0");
 		RETURN_FALSE;
 	}
         
-	RETURN_STRINGL(cursor->columns[(*col)->value.lval].cbuf,
-				   cursor->columns[(*col)->value.lval].cbufl,1);
+	RETURN_STRINGL(cursor->columns[Z_LVAL_PP(col)].cbuf,
+				   cursor->columns[Z_LVAL_PP(col)].cbufl,1);
 }
 /* }}} */
 
@@ -1285,7 +1283,7 @@ PHP_FUNCTION(ora_columntype)
 	}
 
 	convert_to_long_ex(col);
-	colno = (*col)->value.lval;
+	colno = Z_LVAL_PP(col);
 
 	if (cursor->ncols == 0){
 		php_error(E_WARNING, "No tuples available at this cursor index");
@@ -1359,17 +1357,17 @@ PHP_FUNCTION(ora_columnsize)
 		RETURN_FALSE;
 	}
         
-	if ((*col)->value.lval >= cursor->ncols){
+	if (Z_LVAL_PP(col) >= cursor->ncols){
 		php_error(E_WARNING, "Column index larger than number of columns");
 		RETURN_FALSE;
 	}
 
-	if ((*col)->value.lval < 0){
+	if (Z_LVAL_PP(col) < 0){
 		php_error(E_WARNING, "Column numbering starts at 0");
 		RETURN_FALSE;
 	}
         
-	RETURN_LONG(cursor->columns[(*col)->value.lval].dbsize);
+	RETURN_LONG(cursor->columns[Z_LVAL_PP(col)].dbsize);
 }
 /* }}} */
 
@@ -1398,7 +1396,7 @@ PHP_FUNCTION(ora_getcolumn)
 	}
 
 	convert_to_long_ex(col);
-	colno = (*col)->value.lval;        
+	colno = Z_LVAL_PP(col);        
 
 	if (colno >= cursor->ncols){
 		php_error(E_WARNING, "Column index larger than number of columns");
@@ -1763,7 +1761,7 @@ int ora_set_param_values(oraCursor *cursor, int isout TSRMLS_DC)
 		}
 
 		convert_to_string(*pdata);
-		plen = (*pdata)->value.str.len;
+		plen = Z_STRLEN_PP(pdata);
 
  		if (param->progvl <= plen){
   			php_error(E_NOTICE, "Input value will be truncated");
@@ -1771,7 +1769,7 @@ int ora_set_param_values(oraCursor *cursor, int isout TSRMLS_DC)
 
 		len = min(param->progvl - 1, plen);
 
-		strncpy(param->progv, (*pdata)->value.str.val, len);
+		strncpy(param->progv, Z_STRVAL_PP(pdata), len);
 		param->progv[len] = '\0';
 	}
 
@@ -1786,6 +1784,6 @@ int ora_set_param_values(oraCursor *cursor, int isout TSRMLS_DC)
  * tab-width: 4
  * c-basic-offset: 4
  * End:
- * vim600: sw=4 ts=4 tw=78 fdm=marker
- * vim<600: sw=4 ts=4 tw=78
+ * vim600: sw=4 ts=4 fdm=marker
+ * vim<600: sw=4 ts=4
  */
