@@ -1,32 +1,28 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Uwe Steinmann <Uwe.Steinmann@fernuni-hagen.de>              |
+   | Author: Uwe Steinmann <Uwe.Steinmann@fernuni-hagen.de>               |
    +----------------------------------------------------------------------+
 */
 
-/* $Id: php_pdf.h,v 1.19 2001/08/07 17:26:32 phanto Exp $ */
+/* $Id: php_pdf.h,v 1.24.8.3.2.1 2006/01/01 13:46:56 sniper Exp $ */
 
 #ifndef PHP_PDF_H
 #define PHP_PDF_H
 
 #if HAVE_PDFLIB
 
-/* with version 2.20 of pdflib PDF_open_mem isn't available unless
-   the following define isn't there.
-*/
-#define PDF_OPEN_MEM_SUPPORTED
 #include <pdflib.h>
 
 extern zend_module_entry pdf_module_entry;
@@ -42,6 +38,8 @@ PHP_FUNCTION(pdf_get_buffer);	/* new function */
 PHP_FUNCTION(pdf_close);
 PHP_FUNCTION(pdf_begin_page);
 PHP_FUNCTION(pdf_end_page);
+PHP_FUNCTION(pdf_get_majorversion);
+PHP_FUNCTION(pdf_get_minorversion);
 PHP_FUNCTION(pdf_get_value);
 PHP_FUNCTION(pdf_set_value);
 PHP_FUNCTION(pdf_get_parameter);
