@@ -1,22 +1,22 @@
 /* 
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Sascha Schumann <sascha@schumann.cx>                        |
+   | Author: Sascha Schumann <sascha@schumann.cx>                         |
    +----------------------------------------------------------------------+
  */
 
-/* $Id: mod_user.c,v 1.17 2001/07/30 08:24:34 zeev Exp $ */
+/* $Id: mod_user.c,v 1.25.8.1.8.1 2006/01/01 13:46:56 sniper Exp $ */
 
 #include "php.h"
 #include "php_session.h"
@@ -29,33 +29,32 @@ ps_module ps_mod_user = {
 #define SESS_ZVAL_LONG(val, a) 					\
 {											\
 	MAKE_STD_ZVAL(a); 						\
-	a->type = IS_LONG; 						\
-	a->value.lval = val; 					\
+	Z_TYPE_P(a) = IS_LONG; 						\
+	Z_LVAL_P(a) = val; 					\
 }
 
 #define SESS_ZVAL_STRING(vl, a) 					\
 {											\
 	int len = strlen(vl); 					\
 	MAKE_STD_ZVAL(a); 						\
-	a->type = IS_STRING; 					\
-	a->value.str.len = len; 				\
-	a->value.str.val = estrndup(vl, len); 	\
+	Z_TYPE_P(a) = IS_STRING; 					\
+	Z_STRLEN_P(a) = len; 				\
+	Z_STRVAL_P(a) = estrndup(vl, len); 	\
 }
 
 #define SESS_ZVAL_STRINGN(vl, ln, a) 			\
 {											\
 	MAKE_STD_ZVAL(a); 						\
-	a->type = IS_STRING; 					\
-	a->value.str.len = ln; 					\
-	a->value.str.val = estrndup(vl, ln); 	\
+	Z_TYPE_P(a) = IS_STRING; 					\
+	Z_STRLEN_P(a) = ln; 					\
+	Z_STRVAL_P(a) = estrndup(vl, ln); 	\
 }
 
 
-static zval *ps_call_handler(zval *func, int argc, zval **argv)
+static zval *ps_call_handler(zval *func, int argc, zval **argv TSRMLS_DC)
 {
 	int i;
 	zval *retval = NULL;
-	TSRMLS_FETCH();
 	
 	MAKE_STD_ZVAL(retval);
 	if (call_user_function(EG(function_table), NULL, func, retval, 
@@ -83,7 +82,7 @@ static zval *ps_call_handler(zval *func, int argc, zval **argv)
 #define FINISH 								\
 	if (retval) {							\
 		convert_to_long(retval);			\
-		ret = retval->value.lval;			\
+		ret = Z_LVAL_P(retval);			\
 		zval_ptr_dtor(&retval);				\
 	} 										\
 	return ret
@@ -96,7 +95,7 @@ PS_OPEN_FUNC(user)
 	SESS_ZVAL_STRING(save_path, args[0]);
 	SESS_ZVAL_STRING(session_name, args[1]);
 	
-	retval = ps_call_handler(PSF(open), 2, args);
+	retval = ps_call_handler(PSF(open), 2, args TSRMLS_CC);
 	
 	FINISH;
 }
@@ -106,7 +105,7 @@ PS_CLOSE_FUNC(user)
 	int i;
 	STDVARS;
 
-	retval = ps_call_handler(PSF(close), 0, NULL);
+	retval = ps_call_handler(PSF(close), 0, NULL TSRMLS_CC);
 
 	for (i = 0; i < 6; i++)
 		zval_ptr_dtor(&mdata->names[i]);
@@ -124,12 +123,12 @@ PS_READ_FUNC(user)
 
 	SESS_ZVAL_STRING(key, args[0]);
 
-	retval = ps_call_handler(PSF(read), 1, args);
+	retval = ps_call_handler(PSF(read), 1, args TSRMLS_CC);
 	
 	if (retval) {
-		if (retval->type == IS_STRING) {
-			*val = estrndup(retval->value.str.val, retval->value.str.len);
-			*vallen = retval->value.str.len;
+		if (Z_TYPE_P(retval) == IS_STRING) {
+			*val = estrndup(Z_STRVAL_P(retval), Z_STRLEN_P(retval));
+			*vallen = Z_STRLEN_P(retval);
 			ret = SUCCESS;
 		}
 		zval_ptr_dtor(&retval);
@@ -146,7 +145,7 @@ PS_WRITE_FUNC(user)
 	SESS_ZVAL_STRING(key, args[0]);
 	SESS_ZVAL_STRINGN(val, vallen, args[1]);
 
-	retval = ps_call_handler(PSF(write), 2, args);
+	retval = ps_call_handler(PSF(write), 2, args TSRMLS_CC);
 
 	FINISH;
 }
@@ -158,7 +157,7 @@ PS_DESTROY_FUNC(user)
 
 	SESS_ZVAL_STRING(key, args[0]);
 
-	retval = ps_call_handler(PSF(destroy), 1, args);
+	retval = ps_call_handler(PSF(destroy), 1, args TSRMLS_CC);
 
 	FINISH;
 }
@@ -170,7 +169,7 @@ PS_GC_FUNC(user)
 
 	SESS_ZVAL_LONG(maxlifetime, args[0]);
 
-	retval = ps_call_handler(PSF(gc), 1, args);
+	retval = ps_call_handler(PSF(gc), 1, args TSRMLS_CC);
 
 	FINISH;
 }
@@ -180,6 +179,6 @@ PS_GC_FUNC(user)
  * tab-width: 4
  * c-basic-offset: 4
  * End:
- * vim600: sw=4 ts=4 tw=78 fdm=marker
- * vim<600: sw=4 ts=4 tw=78
+ * vim600: sw=4 ts=4 fdm=marker
+ * vim<600: sw=4 ts=4
  */
