@@ -1,13 +1,13 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -17,7 +17,7 @@
  */
 
 
-/* $Id: incomplete_class.c,v 1.11 2001/08/06 13:36:08 thies Exp $ */
+/* $Id: incomplete_class.c,v 1.14.4.5.2.1 2006/01/01 13:46:57 sniper Exp $ */
 
 #include "php.h"
 #include "basic_functions.h"
@@ -26,30 +26,29 @@
 #define INCOMPLETE_CLASS_MSG \
 		"The script tried to execute a method or "  \
 		"access a property of an incomplete object. " \
-		"Please ensure that the class definition <b>%s</b> of the object " \
+		"Please ensure that the class definition %s of the object " \
 		"you are trying to operate on was loaded _before_ " \
 		"the session was started"
 
-#define INCOMPLETE_CLASS "__PHP_Incomplete_Class"
-#define MAGIC_MEMBER "__PHP_Incomplete_Class_Name"
 
 /* {{{ incomplete_class_message
  */
-static void incomplete_class_message(zend_property_reference *ref)
+static void incomplete_class_message(zend_property_reference *ref, int error_type)
 {
 	char buf[1024];
 	char *class_name;
+	TSRMLS_FETCH();
 
-	class_name = php_lookup_class_name(ref->object, NULL, 0);
+	class_name = php_lookup_class_name(ref->object, NULL, 0 TSRMLS_CC);
 	
 	if (!class_name)
 		class_name = estrdup("unknown");
 	
-	snprintf(buf, 1023, INCOMPLETE_CLASS_MSG, class_name);
+	snprintf(buf, sizeof(buf)-1, INCOMPLETE_CLASS_MSG, class_name);
 	
 	efree(class_name);
 
-	php_error(E_ERROR, "%s", buf);
+	php_error_docref(NULL TSRMLS_CC, error_type, "%s", buf);
 }
 /* }}} */
 
@@ -57,7 +56,7 @@ static void incomplete_class_message(zend_property_reference *ref)
  */
 static void incomplete_class_call_func(INTERNAL_FUNCTION_PARAMETERS, zend_property_reference *property_reference)
 {
-	incomplete_class_message(property_reference);
+	incomplete_class_message(property_reference, E_ERROR);
 }
 /* }}} */
 
@@ -65,7 +64,7 @@ static void incomplete_class_call_func(INTERNAL_FUNCTION_PARAMETERS, zend_proper
  */
 static int incomplete_class_set_property(zend_property_reference *property_reference, zval *value)
 {
-	incomplete_class_message(property_reference);
+	incomplete_class_message(property_reference, E_NOTICE);
 	
 	/* does not reach this point */
 	return (0);
@@ -78,7 +77,7 @@ static zval incomplete_class_get_property(zend_property_reference *property_refe
 {
 	zval foo;
 	
-	incomplete_class_message(property_reference);
+	incomplete_class_message(property_reference, E_NOTICE);
 
 	/* does not reach this point */
 	memset(&foo, 0, sizeof(zval)); /* shut warnings up */
@@ -103,7 +102,7 @@ zend_class_entry *php_create_incomplete_class(TSRMLS_D)
 
 /* {{{ php_lookup_class_name
  */
-char *php_lookup_class_name(zval *object, size_t *nlen, zend_bool del)
+char *php_lookup_class_name(zval *object, size_t *nlen, zend_bool del TSRMLS_DC)
 {
 	zval **val;
 	char *retval = NULL;
@@ -116,9 +115,6 @@ char *php_lookup_class_name(zval *object, size_t *nlen, zend_bool del)
 
 		if (nlen)
 			*nlen = Z_STRLEN_PP(val);
-
-		if (del)
-			zend_hash_del(object_properties, MAGIC_MEMBER, sizeof(MAGIC_MEMBER));
 	}
 
 	return (retval);
@@ -127,7 +123,7 @@ char *php_lookup_class_name(zval *object, size_t *nlen, zend_bool del)
 
 /* {{{ php_store_class_name
  */
-void php_store_class_name(zval *object, const char *name, size_t len)
+void php_store_class_name(zval *object, const char *name, size_t len TSRMLS_DC)
 {
 	zval *val;
 
@@ -146,6 +142,6 @@ void php_store_class_name(zval *object, const char *name, size_t len)
  * tab-width: 4
  * c-basic-offset: 4
  * End:
- * vim600: sw=4 ts=4 tw=78 fdm=marker
- * vim<600: sw=4 ts=4 tw=78
+ * vim600: sw=4 ts=4 fdm=marker
+ * vim<600: sw=4 ts=4
  */
