@@ -1,18 +1,18 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Sascha Schumann <sascha@schumann.cx>                        |
+   | Author: Sascha Schumann <sascha@schumann.cx>                         |
    +----------------------------------------------------------------------+
  */
 
@@ -22,19 +22,27 @@
 #include "php_smart_str_public.h"
 
 #include <stdlib.h>
+#ifndef SMART_STR_USE_REALLOC
 #include <zend.h>
+#endif
 
-#define smart_str_0(x) ((x)->c[(x)->len] = '\0')
+#define smart_str_0(x) do { if ((x)->c) { (x)->c[(x)->len] = '\0'; } } while (0)
 
 #ifndef SMART_STR_PREALLOC
 #define SMART_STR_PREALLOC 128
 #endif
 
+#ifdef SMART_STR_USE_REALLOC
+#define SMART_STR_REALLOC(a,b,c) realloc((a),(b))
+#else
+#define SMART_STR_REALLOC(a,b,c) perealloc((a),(b),(c))
+#endif
+
 #define smart_str_alloc(d, n, what) {\
 	if (!d->c) d->len = d->a = 0; \
 	newlen = d->len + n; \
 	if (newlen >= d->a) {\
-		d->c = perealloc(d->c, newlen + SMART_STR_PREALLOC + 1, what); \
+		d->c = SMART_STR_REALLOC(d->c, newlen + SMART_STR_PREALLOC + 1, what); \
 		d->a = newlen + SMART_STR_PREALLOC; \
 	}\
 }
@@ -47,14 +55,15 @@
 #define smart_str_appendl(dest, src, len) smart_str_appendl_ex(dest, src, len, 0)
 #define smart_str_append(dest, src) smart_str_append_ex(dest, src, 0)
 #define smart_str_append_long(dest, val) smart_str_append_long_ex(dest, val, 0)
+#define smart_str_append_unsigned(dest, val) smart_str_append_unsigned_ex(dest, val, 0)
 
-static inline void smart_str_appendc_ex(smart_str *dest, char c, int what)
+static inline void smart_str_appendc_ex(smart_str *dest, unsigned char c, int what)
 {
 	size_t newlen;
 
 	smart_str_alloc(dest, 1, what);
 	dest->len = newlen;
-	dest->c[dest->len - 1] = c;
+	((unsigned char *) dest->c)[dest->len - 1] = c;
 }
 
 
@@ -76,47 +85,50 @@ static inline void smart_str_appendl_ex(smart_str *dest, const char *src, size_t
 	dest->len = newlen;
 }
 
+/* buf points to the END of the buffer */
+static inline char *smart_str_print_unsigned(char *buf, unsigned long num)
+{
+	char *p = buf;
+	
+	*p = '\0';
+	do {
+		*--p = (char)(num % 10) + '0';
+		num /= 10;
+	} while (num > 0);
+
+	return p;
+}
+
+/* buf points to the END of the buffer */
 static inline char *smart_str_print_long(char *buf, long num)
 {
-	char *p = buf, *end;
-	int n;
-	long tmp;
+	char *p;
 	
 	if (num < 0) {
-		num = -num;
-		*p++ = '-';
+		/* this might cause problems when dealing with LONG_MIN
+		   and machines which don't support long long.  Works
+		   flawlessly on 32bit x86 */
+		p = smart_str_print_unsigned(buf, -num);
+		*--p = '-';
+	} else {
+		p = smart_str_print_unsigned(buf, num);
 	}
 
-	/* many numbers are < 10 */
-	if (num < 10) {
-		*p++ = num + '0';
-		return p;
-	}
-
-	n = 1;
-	tmp = num;
-
-	/* calculate the number of digits we need */
-	do {
-		tmp /= 10;
-		n++;
-	} while (tmp >= 10);
-
-	end = p += n;
-	
-	do {
-		*--p = (num % 10) + '0';
-		num /= 10;
-	} while (--n > 0);
-
-	return end;
+	return p;
 }
 
 static inline void smart_str_append_long_ex(smart_str *dest, long num, int type)
 {
 	char buf[32];
-	char *p = smart_str_print_long(buf, num);
-	smart_str_appendl_ex(dest, buf, p - buf, type);
+	char *p = smart_str_print_long(buf + sizeof(buf) - 1, num);
+	smart_str_appendl_ex(dest, p, (buf + sizeof(buf) - 1) - p, type);
+}
+
+static inline void smart_str_append_unsigned_ex(smart_str *dest, long num, int type)
+{
+	char buf[32];
+	char *p = smart_str_print_unsigned(buf + sizeof(buf) - 1, num);
+	smart_str_appendl_ex(dest, p, (buf + sizeof(buf) - 1) - p, type);
 }
 
 static inline void smart_str_append_ex(smart_str *dest, smart_str *src, int what)
