@@ -1,22 +1,22 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors:                                                             |
+   | Author:                                                              |
    +----------------------------------------------------------------------+
 */
 
-/* $Id: php_standard.h,v 1.7.6.1 2001/10/11 01:03:27 ssb Exp $ */
+/* $Id: php_standard.h,v 1.16.4.1.8.1 2006/01/01 13:46:58 sniper Exp $ */
 
 #include "basic_functions.h"
 #include "php_math.h"
@@ -27,6 +27,7 @@
 #include "reg.h"
 #include "php_mail.h"
 #include "md5.h"
+#include "sha1.h"
 #include "html.h"
 #include "exec.h"
 #include "file.h"
@@ -47,7 +48,6 @@
 #include "uniqid.h"
 #include "php_var.h"
 #include "quot_print.h"
-#include "type.h"
 #include "dl.h"
 #include "php_crypt.h"
 #include "head.h"
@@ -57,6 +57,9 @@
 #include "php_array.h"
 #include "php_assert.h"
 #include "php_versioning.h"
+#include "php_ftok.h"
+#include "php_type.h"
+#include "aggregation.h"
 
 #define phpext_standard_ptr basic_functions_module_ptr
 
