@@ -1,23 +1,22 @@
 /* 
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Stig Sther Bakken <ssb@fast.no>                            |
-   |                                                                      |
+   | Author: Stig Sther Bakken <ssb@fast.no>                             |
    +----------------------------------------------------------------------+
 */
 
-/* $Id: php_versioning.h,v 1.2.2.2 2001/10/11 10:40:14 ssb Exp $ */
+/* $Id: php_versioning.h,v 1.5.8.1.8.1 2006/01/01 13:46:58 sniper Exp $ */
 
 #ifndef PHP_VERSIONING_H
 #define PHP_VERSIONING_H
