@@ -1,22 +1,22 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Author: Stig Sther Bakken <ssb@guardian.no>                         |
+   | Author: Stig Sther Bakken <ssb@fast.no>                             |
    +----------------------------------------------------------------------+
  */
 
-/* $Id: uniqid.c,v 1.25 2001/08/11 17:03:37 zeev Exp $ */
+/* $Id: uniqid.c,v 1.31.8.4.8.2 2006/01/01 13:46:58 sniper Exp $ */
 
 #include "php.h"
 
@@ -38,66 +38,65 @@
 #include "php_lcg.h"
 #include "uniqid.h"
 
-#define MORE_ENTROPY (argc == 2 && (*flags)->value.lval)
-
-/* {{{ proto string uniqid(string prefix, [bool more_entropy])
-   Generate a unique id */
+/* {{{ proto string uniqid(string prefix [, bool more_entropy])
+   Generates a unique ID */
+#ifdef HAVE_GETTIMEOFDAY
 PHP_FUNCTION(uniqid)
 {
-#ifdef HAVE_GETTIMEOFDAY
-	pval **prefix, **flags;
+	char *prefix;
+#if defined(__CYGWIN__)
+	zend_bool more_entropy = 1;
+#else
+	zend_bool more_entropy = 0;
+#endif
 	char uniqid[138];
-	int sec, usec, argc;
+	int sec, usec, argc, prefix_len;
 	struct timeval tv;
 
 	argc = ZEND_NUM_ARGS();
-	if (argc < 1 || argc > 2 || zend_get_parameters_ex(argc, &prefix, &flags)) {
-		WRONG_PARAM_COUNT;
-	}
-	convert_to_string_ex(prefix);
-	if (argc == 2) {
-		convert_to_boolean_ex(flags);
+	if (zend_parse_parameters(argc TSRMLS_CC, "s|b", &prefix, &prefix_len,
+							  &more_entropy)) {
+		return;
 	}
 
 	/* Do some bounds checking since we are using a char array. */
-	if ((*prefix)->value.str.len > 114) {
-		php_error(E_WARNING, "The prefix to uniqid should not be more than 114 characters.");
+	if (prefix_len > 114) {
+		php_error_docref(NULL TSRMLS_CC, E_ERROR, "The prefix to uniqid should not be more than 114 characters.");
 		return;
 	}
 #if HAVE_USLEEP && !defined(PHP_WIN32)
-	if (!MORE_ENTROPY) {
+	if (!more_entropy) {
+#if defined(__CYGWIN__)
+		php_error_docref(NULL TSRMLS_CC, E_WARNING, "You must use 'more entropy' under CYGWIN.");
+		RETURN_FALSE;
+#else
 		usleep(1);
+#endif
 	}
 #endif
 	gettimeofday((struct timeval *) &tv, (struct timezone *) NULL);
 	sec = (int) tv.tv_sec;
-	usec = (int) (tv.tv_usec % 1000000);
+	usec = (int) (tv.tv_usec % 0x100000);
 
 	/* The max value usec can have is 0xF423F, so we use only five hex
 	 * digits for usecs.
 	 */
-	if (MORE_ENTROPY) {
-		sprintf(uniqid, "%s%08x%05x%.8f", (*prefix)->value.str.val, sec, usec, php_combined_lcg(TSRMLS_C) * 10);
+	if (more_entropy) {
+		sprintf(uniqid, "%s%08x%05x%.8f", prefix, sec, usec, php_combined_lcg(TSRMLS_C) * 10);
 	} else {
-		sprintf(uniqid, "%s%08x%05x", (*prefix)->value.str.val, sec, usec);
+		sprintf(uniqid, "%s%08x%05x", prefix, sec, usec);
 	}
 
 	RETURN_STRING(uniqid, 1);
-#endif
 }
+#endif
 /* }}} */
 
-function_entry uniqid_functions[] = {
-	PHP_FE(uniqid, NULL)
-	{NULL, NULL, NULL}
-};
-
-
 /*
  * Local variables:
  * tab-width: 4
  * c-basic-offset: 4
  * End:
- * vim600: sw=4 ts=4 tw=78 fdm=marker
- * vim<600: sw=4 ts=4 tw=78
+ * vim600: sw=4 ts=4 fdm=marker
+ * vim<600: sw=4 ts=4
  */
