@@ -3,14 +3,13 @@
 
 #ifdef PHP_WIN32
 #include "config.w32.h"
-#elif defined(NETWARE)
-#include "config.nw.h"
 #else
-#include "php_config.h"
+#include <php_config.h>
 #endif
 
 #if defined(HAVE_BUNDLED_PCRE) || !defined(PHP_VERSION)
 #define pcre_compile 			php_pcre_compile
+#define pcre_compile2 			php_pcre_compile2
 #define pcre_copy_substring		php_pcre_copy_substring
 #define pcre_exec				php_pcre_exec
 #define pcre_get_substring		php_pcre_substring
