@@ -1,18 +1,18 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Zeev Suraski <zeev@zend.com>                                |
+   | Author: Zeev Suraski <zeev@zend.com>                                 |
    +----------------------------------------------------------------------+
 */
 
@@ -57,7 +57,7 @@ struct _php_core_globals {
 	zend_bool allow_call_time_pass_reference;
 	zend_bool implicit_flush;
 
-	int output_buffering;
+	long output_buffering;
 
 	char *safe_mode_include_dir;
 	zend_bool safe_mode_gid;
@@ -66,14 +66,21 @@ struct _php_core_globals {
 
 	char *output_handler;
 
+	char *unserialize_callback_func;
+
 	char *safe_mode_exec_dir;
 
 	long memory_limit;
+	long max_input_time;
 
 	zend_bool track_errors;
 	zend_bool display_errors;
 	zend_bool display_startup_errors;
 	zend_bool log_errors;
+	long      log_errors_max_len;
+	zend_bool ignore_repeated_errors;
+	zend_bool ignore_repeated_source;
+	zend_bool report_memleaks;
 	char *error_log;
 
 	char *doc_root;
@@ -114,6 +121,9 @@ struct _php_core_globals {
 
 	zend_bool y2k_compliance;
 
+	char *docref_root;
+	char *docref_ext;
+
 	zend_bool html_errors;
 	zend_bool xmlrpc_errors;
 
@@ -129,6 +139,8 @@ struct _php_core_globals {
 	zend_bool allow_url_fopen;
 
 	zend_bool always_populate_raw_post_data;
+	
+	long serialize_precision;
 };
 
 
