@@ -20,7 +20,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: cgi_main.c,v 1.190.2.68.2.3 2006/01/01 13:47:01 sniper Exp $ */
+/* $Id: cgi_main.c,v 1.190.2.68.2.5 2006/02/22 15:11:53 dmitry Exp $ */
 
 #include "php.h"
 #include "php_globals.h"
@@ -281,7 +281,7 @@ static void sapi_cgibin_flush(void *server_context)
 #ifndef PHP_WIN32
 		!parent && 
 #endif
-		(!request || FCGX_FFlush(request->out) == -1)) {
+		request && FCGX_FFlush(request->out) == -1) {
 			php_handle_aborted_connection();
 		}
 		return;
@@ -483,7 +483,9 @@ static void sapi_cgi_log_message(char *message)
                                                                                                         
 	if (!FCGX_IsCGI() && logging) {
 		FCGX_Request *request = (FCGX_Request *)SG(server_context);
-		FCGX_FPrintF( request->err, "%s\n", message );
+		if (request) {
+			FCGX_FPrintF( request->err, "%s\n", message );
+		}
 		/* ignore return code */
 	} else
 #endif /* PHP_FASTCGI */
@@ -1260,7 +1262,8 @@ consult the installation file that came with this distribution, or visit \n\
 				fprintf( stderr, "Wait for kids, pid %d\n",
 					 getpid() );
 #endif
-				wait( &status );
+				while (wait( &status ) < 0) {
+				}
 				running--;
 			}
 		}
@@ -1688,6 +1691,7 @@ fastcgi_request_done:
 		exit_status = 255;
 	} zend_end_try();
 
+	SG(server_context) = NULL;
 	php_module_shutdown(TSRMLS_C);
 
 #ifdef ZTS
