@@ -1,13 +1,13 @@
 /* 
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2006 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: roxen.c,v 1.47.2.2 2002/02/03 00:38:00 yohgaki Exp $ */
+/* $Id: roxen.c,v 1.53.2.5.6.1 2006/01/01 13:47:02 sniper Exp $ */
 
 #include "php.h"
 #ifdef HAVE_ROXEN
@@ -438,7 +438,7 @@ static void php_info_roxen(ZEND_MODULE_INFO_FUNC_ARGS)
 {
   /*  char buf[512]; */
   php_info_print_table_start();
-  php_info_print_table_row(2, "SAPI module version", "$Id: roxen.c,v 1.47.2.2 2002/02/03 00:38:00 yohgaki Exp $");
+  php_info_print_table_row(2, "SAPI module version", "$Id: roxen.c,v 1.53.2.5.6.1 2006/01/01 13:47:02 sniper Exp $");
   /*  php_info_print_table_row(2, "Build date", Ns_InfoBuildDate());
       php_info_print_table_row(2, "Config file path", Ns_InfoConfigFile());
       php_info_print_table_row(2, "Error Log path", Ns_InfoErrorLog());
@@ -473,8 +473,7 @@ static zend_module_entry php_roxen_module = {
 
 static int php_roxen_startup(sapi_module_struct *sapi_module)
 {
-  if(php_module_startup(sapi_module) == FAILURE
-     || zend_startup_module(&php_roxen_module) == FAILURE) {
+  if(php_module_startup(sapi_module, &php_roxen_module, 1) == FAILURE) {
     return FAILURE;
   } else {
     return SUCCESS;
@@ -486,7 +485,7 @@ static int php_roxen_startup(sapi_module_struct *sapi_module)
 static sapi_module_struct roxen_sapi_module = {
   "roxen",
   "Roxen",
-  php_module_startup,			/* startup */
+  php_roxen_startup,			/* startup */
   php_module_shutdown_wrapper,		/* shutdown */
   NULL,					/* activate */
   NULL,					/* deactivate */
@@ -576,7 +575,7 @@ static int php_roxen_module_main(TSRMLS_D)
 {
   int res, len;
   char *dir;
-  zend_file_handle file_handle;
+  zend_file_handle file_handle = {0};
 #ifdef ROXEN_USE_ZTS
   GET_THIS();
 #endif
@@ -698,7 +697,7 @@ void pike_module_init( void )
 #endif	 
 #endif
     sapi_startup(&roxen_sapi_module);
-    php_roxen_startup(&roxen_sapi_module);
+    /*php_roxen_startup(&roxen_sapi_module); removed - should be called from SAPI activation*/
     roxen_php_initialized = 1;
     PHP_INIT_LOCK();
   }
